# Copyright 2014-2019 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.



from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_daal_', [dirname(__file__)])
        except ImportError:
            import _daal_
            return _daal_
        if fp is not None:
            try:
                _mod = imp.load_module('_daal_', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _daal_ = swig_import_helper()
    del swig_import_helper
else:
    import _daal_
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


__version__ = "2020.0.0.20191128"
## @package daal Main module


_daal_.batch_swigconstant(_daal_)
batch = _daal_.batch

_daal_.distributed_swigconstant(_daal_)
distributed = _daal_.distributed

_daal_.online_swigconstant(_daal_)
online = _daal_.online

_daal_.step1Local_swigconstant(_daal_)
step1Local = _daal_.step1Local

_daal_.step2Master_swigconstant(_daal_)
step2Master = _daal_.step2Master

_daal_.step3Local_swigconstant(_daal_)
step3Local = _daal_.step3Local

_daal_.step4Local_swigconstant(_daal_)
step4Local = _daal_.step4Local

_daal_.step2Local_swigconstant(_daal_)
step2Local = _daal_.step2Local

_daal_.step3Master_swigconstant(_daal_)
step3Master = _daal_.step3Master

_daal_.step5Master_swigconstant(_daal_)
step5Master = _daal_.step5Master

_daal_.step5Local_swigconstant(_daal_)
step5Local = _daal_.step5Local

_daal_.step6Local_swigconstant(_daal_)
step6Local = _daal_.step6Local

_daal_.step7Master_swigconstant(_daal_)
step7Master = _daal_.step7Master

_daal_.step8Local_swigconstant(_daal_)
step8Local = _daal_.step8Local

_daal_.step9Master_swigconstant(_daal_)
step9Master = _daal_.step9Master

_daal_.step10Local_swigconstant(_daal_)
step10Local = _daal_.step10Local

_daal_.step11Local_swigconstant(_daal_)
step11Local = _daal_.step11Local

_daal_.step12Local_swigconstant(_daal_)
step12Local = _daal_.step12Local

_daal_.step13Local_swigconstant(_daal_)
step13Local = _daal_.step13Local

_daal_.dram_swigconstant(_daal_)
dram = _daal_.dram

_daal_.mcdram_swigconstant(_daal_)
mcdram = _daal_.mcdram
class Base(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, Base, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, Base, name)
    __repr__ = _swig_repr
    __swig_destroy__ = _daal_.delete_Base
    __del__ = lambda self: None

    def __init__(self):
        this = _daal_.new_Base()
        try:
            self.this.append(this)
        except:
            self.this = this
Base_swigregister = _daal_.Base_swigregister
Base_swigregister(Base)
cvar = _daal_.cvar
DAAL_MALLOC_DEFAULT_ALIGNMENT = cvar.DAAL_MALLOC_DEFAULT_ALIGNMENT
SERIALIZATION_HOMOGEN_NT_ID = cvar.SERIALIZATION_HOMOGEN_NT_ID
SERIALIZATION_AOS_NT_ID = cvar.SERIALIZATION_AOS_NT_ID
SERIALIZATION_SOA_NT_ID = cvar.SERIALIZATION_SOA_NT_ID
SERIALIZATION_ARROW_IMMUTABLE_NT_ID = cvar.SERIALIZATION_ARROW_IMMUTABLE_NT_ID
SERIALIZATION_DATACOLLECTION_ID = cvar.SERIALIZATION_DATACOLLECTION_ID
SERIALIZATION_KEYVALUEDATACOLLECTION_ID = cvar.SERIALIZATION_KEYVALUEDATACOLLECTION_ID
SERIALIZATION_DATAFEATURE_NT_ID = cvar.SERIALIZATION_DATAFEATURE_NT_ID
SERIALIZATION_DATADICTIONARY_NT_ID = cvar.SERIALIZATION_DATADICTIONARY_NT_ID
SERIALIZATION_DATADICTIONARY_DS_ID = cvar.SERIALIZATION_DATADICTIONARY_DS_ID
SERIALIZATION_MATRIX_NT_ID = cvar.SERIALIZATION_MATRIX_NT_ID
SERIALIZATION_CSR_NT_ID = cvar.SERIALIZATION_CSR_NT_ID
SERIALIZATION_PACKEDSYMMETRIC_NT_ID = cvar.SERIALIZATION_PACKEDSYMMETRIC_NT_ID
SERIALIZATION_PACKEDTRIANGULAR_NT_ID = cvar.SERIALIZATION_PACKEDTRIANGULAR_NT_ID
SERIALIZATION_MERGE_NT_ID = cvar.SERIALIZATION_MERGE_NT_ID
SERIALIZATION_ROWMERGE_NT_ID = cvar.SERIALIZATION_ROWMERGE_NT_ID
SERIALIZATION_HOMOGEN_TENSOR_ID = cvar.SERIALIZATION_HOMOGEN_TENSOR_ID
SERIALIZATION_TENSOR_OFFSET_LAYOUT_ID = cvar.SERIALIZATION_TENSOR_OFFSET_LAYOUT_ID
SERIALIZATION_MKL_TENSOR_ID = cvar.SERIALIZATION_MKL_TENSOR_ID
SERIALIZATION_OPTIONAL_RESULT_ID = cvar.SERIALIZATION_OPTIONAL_RESULT_ID
SERIALIZATION_MEMORY_BLOCK_ID = cvar.SERIALIZATION_MEMORY_BLOCK_ID
SERIALIZATION_LINEAR_REGRESSION_MODELNORMEQ_ID = cvar.SERIALIZATION_LINEAR_REGRESSION_MODELNORMEQ_ID
SERIALIZATION_LINEAR_REGRESSION_MODELQR_ID = cvar.SERIALIZATION_LINEAR_REGRESSION_MODELQR_ID
SERIALIZATION_LINEAR_REGRESSION_PARTIAL_RESULT_ID = cvar.SERIALIZATION_LINEAR_REGRESSION_PARTIAL_RESULT_ID
SERIALIZATION_LINEAR_REGRESSION_TRAINING_RESULT_ID = cvar.SERIALIZATION_LINEAR_REGRESSION_TRAINING_RESULT_ID
SERIALIZATION_LINEAR_REGRESSION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_LINEAR_REGRESSION_PREDICTION_RESULT_ID
SERIALIZATION_LINEAR_REGRESSION_SINGLE_BETA_RESULT_ID = cvar.SERIALIZATION_LINEAR_REGRESSION_SINGLE_BETA_RESULT_ID
SERIALIZATION_LINEAR_REGRESSION_GROUP_OF_BETAS_RESULT_ID = cvar.SERIALIZATION_LINEAR_REGRESSION_GROUP_OF_BETAS_RESULT_ID
SERIALIZATION_LASSO_REGRESSION_MODEL_ID = cvar.SERIALIZATION_LASSO_REGRESSION_MODEL_ID
SERIALIZATION_LASSO_REGRESSION_TRAINING_RESULT_ID = cvar.SERIALIZATION_LASSO_REGRESSION_TRAINING_RESULT_ID
SERIALIZATION_LASSO_REGRESSION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_LASSO_REGRESSION_PREDICTION_RESULT_ID
SERIALIZATION_PCA_RESULT_ID = cvar.SERIALIZATION_PCA_RESULT_ID
SERIALIZATION_PCA_PARTIAL_RESULT_CORRELATION_ID = cvar.SERIALIZATION_PCA_PARTIAL_RESULT_CORRELATION_ID
SERIALIZATION_PCA_PARTIAL_RESULT_SVD_ID = cvar.SERIALIZATION_PCA_PARTIAL_RESULT_SVD_ID
SERIALIZATION_PCA_TRANSFORM_RESULT_ID = cvar.SERIALIZATION_PCA_TRANSFORM_RESULT_ID
SERIALIZATION_PCA_QUALITY_METRIC_RESULT_ID = cvar.SERIALIZATION_PCA_QUALITY_METRIC_RESULT_ID
SERIALIZATION_STUMP_MODEL_ID = cvar.SERIALIZATION_STUMP_MODEL_ID
SERIALIZATION_STUMP_TRAINING_RESULT_ID = cvar.SERIALIZATION_STUMP_TRAINING_RESULT_ID
SERIALIZATION_STUMP_CLASSIFICATION_MODEL_ID = cvar.SERIALIZATION_STUMP_CLASSIFICATION_MODEL_ID
SERIALIZATION_STUMP_CLASSIFICATION_TRAINING_RESULT_ID = cvar.SERIALIZATION_STUMP_CLASSIFICATION_TRAINING_RESULT_ID
SERIALIZATION_STUMP_REGRESSION_MODEL_ID = cvar.SERIALIZATION_STUMP_REGRESSION_MODEL_ID
SERIALIZATION_STUMP_REGRESSION_TRAINING_RESULT_ID = cvar.SERIALIZATION_STUMP_REGRESSION_TRAINING_RESULT_ID
SERIALIZATION_STUMP_REGRESSION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_STUMP_REGRESSION_PREDICTION_RESULT_ID
SERIALIZATION_ADABOOST_MODEL_ID = cvar.SERIALIZATION_ADABOOST_MODEL_ID
SERIALIZATION_ADABOOST_TRAINING_RESULT_ID = cvar.SERIALIZATION_ADABOOST_TRAINING_RESULT_ID
SERIALIZATION_MULTICLASS_ADABOOST_MODEL_ID = cvar.SERIALIZATION_MULTICLASS_ADABOOST_MODEL_ID
SERIALIZATION_MULTICLASS_ADABOOST_TRAINING_RESULT_ID = cvar.SERIALIZATION_MULTICLASS_ADABOOST_TRAINING_RESULT_ID
SERIALIZATION_BROWNBOOST_MODEL_ID = cvar.SERIALIZATION_BROWNBOOST_MODEL_ID
SERIALIZATION_BROWNBOOST_TRAINING_RESULT_ID = cvar.SERIALIZATION_BROWNBOOST_TRAINING_RESULT_ID
SERIALIZATION_LOGITBOOST_MODEL_ID = cvar.SERIALIZATION_LOGITBOOST_MODEL_ID
SERIALIZATION_LOGITBOOST_TRAINING_RESULT_ID = cvar.SERIALIZATION_LOGITBOOST_TRAINING_RESULT_ID
SERIALIZATION_NAIVE_BAYES_MODEL_ID = cvar.SERIALIZATION_NAIVE_BAYES_MODEL_ID
SERIALIZATION_NAIVE_BAYES_PARTIALMODEL_ID = cvar.SERIALIZATION_NAIVE_BAYES_PARTIALMODEL_ID
SERIALIZATION_NAIVE_BAYES_RESULT_ID = cvar.SERIALIZATION_NAIVE_BAYES_RESULT_ID
SERIALIZATION_NAIVE_BAYES_PARTIAL_RESULT_ID = cvar.SERIALIZATION_NAIVE_BAYES_PARTIAL_RESULT_ID
SERIALIZATION_SVM_MODEL_ID = cvar.SERIALIZATION_SVM_MODEL_ID
SERIALIZATION_SVM_TRAINING_RESULT_ID = cvar.SERIALIZATION_SVM_TRAINING_RESULT_ID
SERIALIZATION_MULTI_CLASS_CLASSIFIER_MODEL_ID = cvar.SERIALIZATION_MULTI_CLASS_CLASSIFIER_MODEL_ID
SERIALIZATION_MULTICLASS_CLASSIFIER_RESULT_ID = cvar.SERIALIZATION_MULTICLASS_CLASSIFIER_RESULT_ID
SERIALIZATION_COVARIANCE_PARTIAL_RESULT_ID = cvar.SERIALIZATION_COVARIANCE_PARTIAL_RESULT_ID
SERIALIZATION_COVARIANCE_RESULT_ID = cvar.SERIALIZATION_COVARIANCE_RESULT_ID
SERIALIZATION_KMEANS_PARTIAL_RESULT_ID = cvar.SERIALIZATION_KMEANS_PARTIAL_RESULT_ID
SERIALIZATION_KMEANS_RESULT_ID = cvar.SERIALIZATION_KMEANS_RESULT_ID
SERIALIZATION_KMEANS_INIT_PARTIAL_RESULT_ID = cvar.SERIALIZATION_KMEANS_INIT_PARTIAL_RESULT_ID
SERIALIZATION_KMEANS_INIT_STEP2LOCAL_PP_PARTIAL_RESULT_ID = cvar.SERIALIZATION_KMEANS_INIT_STEP2LOCAL_PP_PARTIAL_RESULT_ID
SERIALIZATION_KMEANS_INIT_STEP3MASTER_PP_PARTIAL_RESULT_ID = cvar.SERIALIZATION_KMEANS_INIT_STEP3MASTER_PP_PARTIAL_RESULT_ID
SERIALIZATION_KMEANS_INIT_STEP4LOCAL_PP_PARTIAL_RESULT_ID = cvar.SERIALIZATION_KMEANS_INIT_STEP4LOCAL_PP_PARTIAL_RESULT_ID
SERIALIZATION_KMEANS_INIT_STEP5MASTER_PP_PARTIAL_RESULT_ID = cvar.SERIALIZATION_KMEANS_INIT_STEP5MASTER_PP_PARTIAL_RESULT_ID
SERIALIZATION_KMEANS_INIT_RESULT_ID = cvar.SERIALIZATION_KMEANS_INIT_RESULT_ID
SERIALIZATION_CLASSIFIER_TRAINING_PARTIAL_RESULT_ID = cvar.SERIALIZATION_CLASSIFIER_TRAINING_PARTIAL_RESULT_ID
SERIALIZATION_CLASSIFIER_BINARY_CONFUSION_MATRIX_RESULT_ID = cvar.SERIALIZATION_CLASSIFIER_BINARY_CONFUSION_MATRIX_RESULT_ID
SERIALIZATION_CLASSIFIER_MULTICLASS_CONFUSION_MATRIX_RESULT_ID = cvar.SERIALIZATION_CLASSIFIER_MULTICLASS_CONFUSION_MATRIX_RESULT_ID
SERIALIZATION_CLASSIFIER_PREDICTION_RESULT_ID = cvar.SERIALIZATION_CLASSIFIER_PREDICTION_RESULT_ID
SERIALIZATION_CLASSIFIER_TRAINING_RESULT_ID = cvar.SERIALIZATION_CLASSIFIER_TRAINING_RESULT_ID
SERIALIZATION_MOMENTS_PARTIAL_RESULT_ID = cvar.SERIALIZATION_MOMENTS_PARTIAL_RESULT_ID
SERIALIZATION_MOMENTS_RESULT_ID = cvar.SERIALIZATION_MOMENTS_RESULT_ID
SERIALIZATION_IMPLICIT_ALS_MODEL_ID = cvar.SERIALIZATION_IMPLICIT_ALS_MODEL_ID
SERIALIZATION_IMPLICIT_ALS_PARTIALMODEL_ID = cvar.SERIALIZATION_IMPLICIT_ALS_PARTIALMODEL_ID
SERIALIZATION_IMPLICIT_ALS_PREDICTION_RATINGS_PARTIAL_RESULT_ID = cvar.SERIALIZATION_IMPLICIT_ALS_PREDICTION_RATINGS_PARTIAL_RESULT_ID
SERIALIZATION_IMPLICIT_ALS_PREDICTION_RATINGS_RESULT_ID = cvar.SERIALIZATION_IMPLICIT_ALS_PREDICTION_RATINGS_RESULT_ID
SERIALIZATION_IMPLICIT_ALS_TRAINING_INIT_RESULT_ID = cvar.SERIALIZATION_IMPLICIT_ALS_TRAINING_INIT_RESULT_ID
SERIALIZATION_IMPLICIT_ALS_TRAINING_INIT_PARTIAL_RESULT_BASE_ID = cvar.SERIALIZATION_IMPLICIT_ALS_TRAINING_INIT_PARTIAL_RESULT_BASE_ID
SERIALIZATION_IMPLICIT_ALS_TRAINING_INIT_PARTIAL_RESULT_ID = cvar.SERIALIZATION_IMPLICIT_ALS_TRAINING_INIT_PARTIAL_RESULT_ID
SERIALIZATION_IMPLICIT_ALS_TRAINING_INIT_DISTRIBUTED_PARTIAL_RESULT_STEP2_ID = cvar.SERIALIZATION_IMPLICIT_ALS_TRAINING_INIT_DISTRIBUTED_PARTIAL_RESULT_STEP2_ID
SERIALIZATION_IMPLICIT_ALS_TRAINING_RESULT_ID = cvar.SERIALIZATION_IMPLICIT_ALS_TRAINING_RESULT_ID
SERIALIZATION_IMPLICIT_ALS_DISTRIBUTED_PARTIAL_RESULT_STEP1_ID = cvar.SERIALIZATION_IMPLICIT_ALS_DISTRIBUTED_PARTIAL_RESULT_STEP1_ID
SERIALIZATION_IMPLICIT_ALS_DISTRIBUTED_PARTIAL_RESULT_STEP2_ID = cvar.SERIALIZATION_IMPLICIT_ALS_DISTRIBUTED_PARTIAL_RESULT_STEP2_ID
SERIALIZATION_IMPLICIT_ALS_DISTRIBUTED_PARTIAL_RESULT_STEP3_ID = cvar.SERIALIZATION_IMPLICIT_ALS_DISTRIBUTED_PARTIAL_RESULT_STEP3_ID
SERIALIZATION_IMPLICIT_ALS_DISTRIBUTED_PARTIAL_RESULT_STEP4_ID = cvar.SERIALIZATION_IMPLICIT_ALS_DISTRIBUTED_PARTIAL_RESULT_STEP4_ID
SERIALIZATION_ASSOCIATION_RULES_RESULT_ID = cvar.SERIALIZATION_ASSOCIATION_RULES_RESULT_ID
SERIALIZATION_CHOLESKY_RESULT_ID = cvar.SERIALIZATION_CHOLESKY_RESULT_ID
SERIALIZATION_CORRELATION_DISTANCE_RESULT_ID = cvar.SERIALIZATION_CORRELATION_DISTANCE_RESULT_ID
SERIALIZATION_COSINE_DISTANCE_RESULT_ID = cvar.SERIALIZATION_COSINE_DISTANCE_RESULT_ID
SERIALIZATION_EM_GMM_INIT_RESULT_ID = cvar.SERIALIZATION_EM_GMM_INIT_RESULT_ID
SERIALIZATION_EM_GMM_RESULT_ID = cvar.SERIALIZATION_EM_GMM_RESULT_ID
SERIALIZATION_KERNEL_FUNCTION_RESULT_ID = cvar.SERIALIZATION_KERNEL_FUNCTION_RESULT_ID
SERIALIZATION_OUTLIER_DETECTION_MULTIVARIATE_RESULT_ID = cvar.SERIALIZATION_OUTLIER_DETECTION_MULTIVARIATE_RESULT_ID
SERIALIZATION_OUTLIER_DETECTION_UNIVARIATE_RESULT_ID = cvar.SERIALIZATION_OUTLIER_DETECTION_UNIVARIATE_RESULT_ID
SERIALIZATION_OUTLIER_DETECTION_BACON_RESULT_ID = cvar.SERIALIZATION_OUTLIER_DETECTION_BACON_RESULT_ID
SERIALIZATION_PIVOTED_QR_RESULT_ID = cvar.SERIALIZATION_PIVOTED_QR_RESULT_ID
SERIALIZATION_QR_RESULT_ID = cvar.SERIALIZATION_QR_RESULT_ID
SERIALIZATION_QR_ONLINE_PARTIAL_RESULT_ID = cvar.SERIALIZATION_QR_ONLINE_PARTIAL_RESULT_ID
SERIALIZATION_QR_DISTRIBUTED_PARTIAL_RESULT_ID = cvar.SERIALIZATION_QR_DISTRIBUTED_PARTIAL_RESULT_ID
SERIALIZATION_QR_DISTRIBUTED_PARTIAL_RESULT_STEP3_ID = cvar.SERIALIZATION_QR_DISTRIBUTED_PARTIAL_RESULT_STEP3_ID
SERIALIZATION_QUANTILES_RESULT_ID = cvar.SERIALIZATION_QUANTILES_RESULT_ID
SERIALIZATION_WEAK_LEARNER_RESULT_ID = cvar.SERIALIZATION_WEAK_LEARNER_RESULT_ID
SERIALIZATION_SVD_RESULT_ID = cvar.SERIALIZATION_SVD_RESULT_ID
SERIALIZATION_SVD_ONLINE_PARTIAL_RESULT_ID = cvar.SERIALIZATION_SVD_ONLINE_PARTIAL_RESULT_ID
SERIALIZATION_SVD_DISTRIBUTED_PARTIAL_RESULT_ID = cvar.SERIALIZATION_SVD_DISTRIBUTED_PARTIAL_RESULT_ID
SERIALIZATION_SVD_DISTRIBUTED_PARTIAL_RESULT_STEP3_ID = cvar.SERIALIZATION_SVD_DISTRIBUTED_PARTIAL_RESULT_STEP3_ID
SERIALIZATION_RELU_RESULT_ID = cvar.SERIALIZATION_RELU_RESULT_ID
SERIALIZATION_SORTING_RESULT_ID = cvar.SERIALIZATION_SORTING_RESULT_ID
SERIALIZATION_SOFTMAX_RESULT_ID = cvar.SERIALIZATION_SOFTMAX_RESULT_ID
SERIALIZATION_LOGISTIC_RESULT_ID = cvar.SERIALIZATION_LOGISTIC_RESULT_ID
SERIALIZATION_TANH_RESULT_ID = cvar.SERIALIZATION_TANH_RESULT_ID
SERIALIZATION_SMOOTHRELU_RESULT_ID = cvar.SERIALIZATION_SMOOTHRELU_RESULT_ID
SERIALIZATION_ABS_RESULT_ID = cvar.SERIALIZATION_ABS_RESULT_ID
SERIALIZATION_OBJECTIVE_FUNCTION_RESULT_ID = cvar.SERIALIZATION_OBJECTIVE_FUNCTION_RESULT_ID
SERIALIZATION_ITERATIVE_SOLVER_RESULT_ID = cvar.SERIALIZATION_ITERATIVE_SOLVER_RESULT_ID
SERIALIZATION_ADAGRAD_RESULT_ID = cvar.SERIALIZATION_ADAGRAD_RESULT_ID
SERIALIZATION_LBFGS_RESULT_ID = cvar.SERIALIZATION_LBFGS_RESULT_ID
SERIALIZATION_SGD_RESULT_ID = cvar.SERIALIZATION_SGD_RESULT_ID
SERIALIZATION_SAGA_RESULT_ID = cvar.SERIALIZATION_SAGA_RESULT_ID
SERIALIZATION_COORDINATE_DESCENT_RESULT_ID = cvar.SERIALIZATION_COORDINATE_DESCENT_RESULT_ID
SERIALIZATION_NORMALIZATION_ZSCORE_RESULT_ID = cvar.SERIALIZATION_NORMALIZATION_ZSCORE_RESULT_ID
SERIALIZATION_NORMALIZATION_MINMAX_RESULT_ID = cvar.SERIALIZATION_NORMALIZATION_MINMAX_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_TRAINING_MODEL_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_TRAINING_MODEL_ID
SERIALIZATION_NEURAL_NETWORKS_PREDICTION_MODEL_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_PREDICTION_MODEL_ID
SERIALIZATION_NEURAL_NETWORKS_NUMERIC_TABLE_WEIGHTS_AND_BIASES_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_NUMERIC_TABLE_WEIGHTS_AND_BIASES_ID
SERIALIZATION_NEURAL_NETWORKS_NUMERIC_TABLE_WEIGHTS_AND_BIASES_DERIVATIVES_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_NUMERIC_TABLE_WEIGHTS_AND_BIASES_DERIVATIVES_ID
SERIALIZATION_NEURAL_NETWORKS_TENSOR_WEIGHTS_AND_BIASES_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_TENSOR_WEIGHTS_AND_BIASES_ID
SERIALIZATION_NEURAL_NETWORKS_TENSOR_WEIGHTS_AND_BIASES_DERIVATIVES_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_TENSOR_WEIGHTS_AND_BIASES_DERIVATIVES_ID
SERIALIZATION_NEURAL_NETWORKS_TRAINING_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_TRAINING_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_TRAINING_PARTIAL_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_TRAINING_PARTIAL_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_TRAINING_DISTRIBUTED_PARTIAL_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_TRAINING_DISTRIBUTED_PARTIAL_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_PREDICTION_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_PREDICTION_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_ABS_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_ABS_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_ABS_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_ABS_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOGISTIC_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOGISTIC_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOGISTIC_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOGISTIC_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_RELU_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_RELU_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_RELU_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_RELU_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SMOOTHRELU_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SMOOTHRELU_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SMOOTHRELU_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SMOOTHRELU_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_TANH_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_TANH_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_TANH_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_TANH_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_PRELU_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_PRELU_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_PRELU_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_PRELU_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SOFTMAX_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SOFTMAX_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SOFTMAX_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SOFTMAX_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_FULLYCONNECTED_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_FULLYCONNECTED_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_FULLYCONNECTED_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_FULLYCONNECTED_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_DROPOUT_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_DROPOUT_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_DROPOUT_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_DROPOUT_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_BATCH_NORMALIZATION_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_BATCH_NORMALIZATION_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_BATCH_NORMALIZATION_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_BATCH_NORMALIZATION_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LRN_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LRN_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LRN_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LRN_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPLIT_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPLIT_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPLIT_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPLIT_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_CONVOLUTION2D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_CONVOLUTION2D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_CONVOLUTION2D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_CONVOLUTION2D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_CONCAT_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_CONCAT_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_CONCAT_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_CONCAT_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING1D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING1D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING1D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING1D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING1D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING1D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING1D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING1D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING2D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING2D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING2D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING2D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING2D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING2D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING2D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING2D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING3D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING3D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING3D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING3D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING3D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_MAXIMUM_POOLING3D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING3D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_AVERAGE_POOLING3D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOSS_SOFTMAX_CROSS_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOSS_SOFTMAX_CROSS_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOSS_SOFTMAX_CROSS_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOSS_SOFTMAX_CROSS_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_STOCHASTIC_POOLING2D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_STOCHASTIC_POOLING2D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_STOCHASTIC_POOLING2D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_STOCHASTIC_POOLING2D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOCALLYCONNECTED2D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOCALLYCONNECTED2D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOCALLYCONNECTED2D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOCALLYCONNECTED2D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LCN_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LCN_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LCN_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LCN_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_AVERAGE_POOLING2D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_AVERAGE_POOLING2D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_AVERAGE_POOLING2D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_AVERAGE_POOLING2D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_MAXIMUM_POOLING2D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_MAXIMUM_POOLING2D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_MAXIMUM_POOLING2D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_MAXIMUM_POOLING2D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_STOCHASTIC_POOLING2D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_STOCHASTIC_POOLING2D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_STOCHASTIC_POOLING2D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_SPATIAL_STOCHASTIC_POOLING2D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_TRANSPOSED_CONV2D_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_TRANSPOSED_CONV2D_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_TRANSPOSED_CONV2D_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_TRANSPOSED_CONV2D_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOSS_LOGISTIC_CROSS_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOSS_LOGISTIC_CROSS_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOSS_LOGISTIC_CROSS_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_LOSS_LOGISTIC_CROSS_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_RESHAPE_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_RESHAPE_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_RESHAPE_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_RESHAPE_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_ELTWISE_SUM_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_ELTWISE_SUM_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_ELTWISE_SUM_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_ELTWISE_SUM_BACKWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_ELU_FORWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_ELU_FORWARD_RESULT_ID
SERIALIZATION_NEURAL_NETWORKS_LAYERS_ELU_BACKWARD_RESULT_ID = cvar.SERIALIZATION_NEURAL_NETWORKS_LAYERS_ELU_BACKWARD_RESULT_ID
SERIALIZATION_RIDGE_REGRESSION_MODELNORMEQ_ID = cvar.SERIALIZATION_RIDGE_REGRESSION_MODELNORMEQ_ID
SERIALIZATION_RIDGE_REGRESSION_PARTIAL_RESULT_ID = cvar.SERIALIZATION_RIDGE_REGRESSION_PARTIAL_RESULT_ID
SERIALIZATION_RIDGE_REGRESSION_TRAINING_RESULT_ID = cvar.SERIALIZATION_RIDGE_REGRESSION_TRAINING_RESULT_ID
SERIALIZATION_RIDGE_REGRESSION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_RIDGE_REGRESSION_PREDICTION_RESULT_ID
SERIALIZATION_K_NEAREST_NEIGHBOR_MODEL_ID = cvar.SERIALIZATION_K_NEAREST_NEIGHBOR_MODEL_ID
SERIALIZATION_K_NEAREST_NEIGHBOR_TRAINING_RESULT_ID = cvar.SERIALIZATION_K_NEAREST_NEIGHBOR_TRAINING_RESULT_ID
SERIALIZATION_DECISION_FOREST_CLASSIFICATION_MODEL_ID = cvar.SERIALIZATION_DECISION_FOREST_CLASSIFICATION_MODEL_ID
SERIALIZATION_DECISION_FOREST_CLASSIFICATION_TRAINING_RESULT_ID = cvar.SERIALIZATION_DECISION_FOREST_CLASSIFICATION_TRAINING_RESULT_ID
SERIALIZATION_DECISION_FOREST_CLASSIFICATION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_DECISION_FOREST_CLASSIFICATION_PREDICTION_RESULT_ID
SERIALIZATION_DECISION_FOREST_REGRESSION_MODEL_ID = cvar.SERIALIZATION_DECISION_FOREST_REGRESSION_MODEL_ID
SERIALIZATION_DECISION_FOREST_REGRESSION_TRAINING_RESULT_ID = cvar.SERIALIZATION_DECISION_FOREST_REGRESSION_TRAINING_RESULT_ID
SERIALIZATION_DECISION_FOREST_REGRESSION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_DECISION_FOREST_REGRESSION_PREDICTION_RESULT_ID
SERIALIZATION_GBT_CLASSIFICATION_MODEL_ID = cvar.SERIALIZATION_GBT_CLASSIFICATION_MODEL_ID
SERIALIZATION_GBT_CLASSIFICATION_TRAINING_RESULT_ID = cvar.SERIALIZATION_GBT_CLASSIFICATION_TRAINING_RESULT_ID
SERIALIZATION_GBT_CLASSIFICATION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_GBT_CLASSIFICATION_PREDICTION_RESULT_ID
SERIALIZATION_GBT_REGRESSION_MODEL_ID = cvar.SERIALIZATION_GBT_REGRESSION_MODEL_ID
SERIALIZATION_GBT_REGRESSION_TRAINING_RESULT_ID = cvar.SERIALIZATION_GBT_REGRESSION_TRAINING_RESULT_ID
SERIALIZATION_GBT_REGRESSION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_GBT_REGRESSION_PREDICTION_RESULT_ID
SERIALIZATION_GBT_DECISION_TREE_ID = cvar.SERIALIZATION_GBT_DECISION_TREE_ID
SERIALIZATION_DECISION_TREE_CLASSIFICATION_MODEL_ID = cvar.SERIALIZATION_DECISION_TREE_CLASSIFICATION_MODEL_ID
SERIALIZATION_DECISION_TREE_CLASSIFICATION_TRAINING_RESULT_ID = cvar.SERIALIZATION_DECISION_TREE_CLASSIFICATION_TRAINING_RESULT_ID
SERIALIZATION_DECISION_TREE_REGRESSION_MODEL_ID = cvar.SERIALIZATION_DECISION_TREE_REGRESSION_MODEL_ID
SERIALIZATION_DECISION_TREE_REGRESSION_TRAINING_RESULT_ID = cvar.SERIALIZATION_DECISION_TREE_REGRESSION_TRAINING_RESULT_ID
SERIALIZATION_DECISION_TREE_REGRESSION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_DECISION_TREE_REGRESSION_PREDICTION_RESULT_ID
SERIALIZATION_REGRESSION_TRAINING_RESULT_ID = cvar.SERIALIZATION_REGRESSION_TRAINING_RESULT_ID
SERIALIZATION_REGRESSION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_REGRESSION_PREDICTION_RESULT_ID
SERIALIZATION_LM_TRAINING_RESULT_ID = cvar.SERIALIZATION_LM_TRAINING_RESULT_ID
SERIALIZATION_LM_PREDICTION_RESULT_ID = cvar.SERIALIZATION_LM_PREDICTION_RESULT_ID
SERIALIZATION_LOGISTIC_REGRESSION_MODEL_ID = cvar.SERIALIZATION_LOGISTIC_REGRESSION_MODEL_ID
SERIALIZATION_LOGISTIC_REGRESSION_TRAINING_RESULT_ID = cvar.SERIALIZATION_LOGISTIC_REGRESSION_TRAINING_RESULT_ID
SERIALIZATION_LOGISTIC_REGRESSION_PREDICTION_RESULT_ID = cvar.SERIALIZATION_LOGISTIC_REGRESSION_PREDICTION_RESULT_ID
SERIALIZATION_DBSCAN_RESULT_ID = cvar.SERIALIZATION_DBSCAN_RESULT_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP1_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP1_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP2_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP2_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP3_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP3_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP4_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP4_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP5_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP5_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP6_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP6_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP7_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP7_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP8_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP8_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP9_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP9_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_RESULT_STEP9_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_RESULT_STEP9_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP10_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP10_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP11_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP11_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP12_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP12_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_RESULT_STEP13_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_RESULT_STEP13_ID
SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP13_ID = cvar.SERIALIZATION_DBSCAN_DISTRIBUTED_PARTIAL_RESULT_STEP13_ID

from numpy import float64, float32, intc


# This file is compatible with both classic and new-style classes.


